#ifndef _AEON_HEADER_
#define _AEON_HEADER_

/* various lengths taken from rfc 821*/
#define MAX_LEN 512  /* max command line length */
#define TXT_LEN 1000 /* max txt line length */ 
#define DOM_LEN 64   /* max domain name */
#define PATH_LEN 256 /* max reverse path length */
#define MAX_RCPT 100 /* max recipients number */

/* server responses */
#define REP_ALLOK 250 /* standard ok */
#define REP_READY 220 /* service ready (first server msg) */
#define REP_SMAIL 354 /* start mail input */
#define REP_CLOSE 221 /* closing (QUIT response) */
#define REP_AUTOK 235 /* authorization successfull */

/* authorization methods */
#define AUTH_NONE 1  /* no method found, will try send anyway */
#define AUTH_PLAIN 2 /* PLAIN method found */

#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <ctype.h> 	/* isspace */
#include <netinet/in.h>
#include <arpa/inet.h>
#include <unistd.h>
#include <netdb.h> 	/* struct hostent */
#include <strings.h> 	/* bzero, etc */
#include <string.h>
#include <time.h>

#define PORT 25

#define MAX_SETTINGS 6 /* number of lines (settings) in rc file */

/* from aeonlib.c */
int parseReply(char *resp);
void logTimestamp(const char *logfile);
int getConfig(char settings[MAX_SETTINGS][MAX_LEN]);
int setup(char settings[MAX_SETTINGS][MAX_LEN], int numSet, char *sender, char *server, 
		char *hostname, char *login, char *password, char *logfile);
char *rmSpaces(char *str);
int getMessageHeader(char **addressList, char *headerFile);
int extractMailAddr(char **addressList, int pos, char *str);
void authCat(char *user, char *pass, char *target);

/* from aeon.c */
int establishConnection(char *serverName);
int sayEHLO(int mySocket, char *myHostname);
int authorizePlain(int mySocket, char *login, char *password);
int sayWho(int mySocket, char *mailAddress);
int sayWhere(int mySocket, char *mailAddress);
int sendMessageHeader(int mySocket, char *headerFile);
int sendData(int mySocket);
int sayQuit(int mySocket);
int logEntry(const char *entry);

/* from base64.c */
int encodeB64(char const *src, size_t srcLen, char *targ, size_t targLen);

#endif
