#include "aeon.h"

/* returns number of server's response */
int parseReply(char *resp)
{
	char value[4];

	strncpy(value, resp, 3);
	return atoi(value);
}

/* reading rc file, handling missing options */
int getConfig(char settings[MAX_SETTINGS][MAX_LEN])
{
	char home[MAX_LEN];
	FILE *fp;				/* .rc file handler */
	int numSet = 0;				/* number of settings */

	strcpy(home, getenv("HOME"));		/* get home path */
	strcat(home, "/.aeonrc");		/* full path to rc file */
	fp = fopen(home, "r");		
	if (fp == NULL) return -1; 		/* no cfg - ERROR */
	while (fgets(settings[numSet], MAX_LEN-1, fp) && (numSet < MAX_SETTINGS)) numSet++;
	fclose(fp);

	return numSet;
}

/* matching program variables with rc file settings */
int setup(char settings[MAX_SETTINGS][MAX_LEN], int numSet, char *sender, 
		char *server, char *hostname, char *login, char *pass, char *logfile)
{
	char keyword[MAX_LEN], value[MAX_LEN];
	char *tmpPtr;
	int i;

	*login = *pass = *server = *sender = *hostname = *logfile = '\0';
	/* match line "keyword = value" with appropriate variable
	 * cut "keyword =" and unneccessary blanks.
	 * check if value has appropriate length */
	for (i=0; i<numSet; i++) {
		tmpPtr = strchr(settings[i], '=');		/* find '=' symbol */
		if (tmpPtr) {					/* is it valid keyword=value line? */
			*tmpPtr = '\0';				/* replace '=' with '\0'... */
			strcpy(keyword, rmSpaces(settings[i]));	/* ... so we have keyword */
			tmpPtr++;				/* and after '\0'... */
			strcpy(value, tmpPtr);			/* ... we have the value - voilla!*/
			if (strcmp(keyword, "login") == 0) 	/* matching */
				strncpy(login, rmSpaces(value), DOM_LEN);
			if (strcmp(keyword, "pass") == 0) 
				strncpy(pass, rmSpaces(value), DOM_LEN);
			if (strcmp(keyword, "server") == 0) 
				strncpy(server, rmSpaces(value), DOM_LEN);
			if (strcmp(keyword, "sender") == 0) 
				strncpy(sender, rmSpaces(value), PATH_LEN);
			if (strcmp(keyword, "hostname") == 0) 
				strncpy(hostname, rmSpaces(value), DOM_LEN);
			if (strcmp(keyword, "logfile") == 0) 
				strncpy(logfile, rmSpaces(value), DOM_LEN);
		}
	}
	
	if ((strlen(sender) == 0) || (strlen(server) == 0)) return -1;
	if (strlen(hostname) == 0) strcpy(hostname, "localhost.localdomain");
	if ((strlen(login) == 0) || (strlen(pass) == 0)) return 1;

	return 0;
}

/* remove leading and trailing spaces */
char *rmSpaces(char *str)
{
	/* the only char expected to be negative value is EOF
	 * since we will not have EOF here, we can safely declare unsigned
	 * char here, avoiding "subscript has type char" warning in 
	 * isspace() function on some platforms */
	unsigned char *begin, *end;

	begin = (unsigned char*) str;
	while (isspace(*begin)) begin++;  			/* get rid of blanks before */
	end = begin;
	while (!isspace(*end)) end++; 			/* get rid of blanks after setting */
	*end = '\0';
	
	return (char*) begin;
}

/* put time and date into log file */
void logTimestamp(const char *logfile)
{
	FILE *lf;
	time_t now;

	time(&now); 
	lf = fopen(logfile, "a");
	if (lf) {
		fprintf(lf, "\n%s\n", ctime(&now));
		fclose(lf);
	}
}

/* get to: cc: bcc: and subject: lines from message header
 * parse addresses and put into list, return number of messages */
int getMessageHeader(char **addressList, char *headerFile)
{	
	char str[TXT_LEN];				/* temp line of header file 		*/
	char to[TXT_LEN], cc[TXT_LEN], bcc[TXT_LEN];
	int num = 0;					/* number of addresses processed 	*/
	unsigned char done = 0;				/* bool 				*/
	int fd;						/* tmp file descriptor 			*/

	*to = *cc = *bcc = '\0';
	
	if ((fd = mkstemp(headerFile)) == -1) {
		perror("mkstemp");
		return -1;
	}
	/* get "to: someone", "cc: someone", "bcc: someone" lines from stdin
	 * copy all header lines to a temp file. addresses are needer for
	 * sayWhere function, header will be send later as a data */
	do {
		fgets(str, TXT_LEN-3, stdin);		/* line\r\n\0 */
		if ((strncmp(str, "to:", 3) == 0) || (strncmp(str, "To:", 3) == 0)) 
			strcpy(to, str);
		if ((strncmp(str, "cc:", 3) == 0) || (strncmp(str, "Cc:", 3) == 0)) 
			strcpy(cc, str);
		if ((strncmp(str, "bcc:", 4) == 0) || (strncmp(str, "Bcc:", 4) == 0)) 
			strcpy(bcc, str);
		if (strcmp(str, "\n") == 0) done = 1;
		write(fd, str, strlen(str));
	} while (!done);
	close(fd);

	/* fill address list with email addresses from to:, cc: and bcc: lines */
	if (strlen(to)) {
		strcpy(str, to);
		num = extractMailAddr(addressList, 0, str);
	}
	if (strlen(cc)) {
		strcpy(str, cc);
		num = extractMailAddr(addressList, num, str);
	}
	if (strlen(bcc)) {
		strcpy(str, bcc);
		num = extractMailAddr(addressList, num, str);
	}
	
	return num; 					/* number of recipients */
}

/* rip email addresses from to: cc: or bcc: string.
 * get 100 recipients tops */
int extractMailAddr(char **addressList, int pos, char *str)
{
	char *ptr; 					/* temp */
	int len, num;   				/* num - position on addressList */

	num = pos;
	ptr = strtok(str, " "); 			/* go after "to:" "cc:" or "bcc:"*/
	while ((ptr = strtok(NULL, " ")) != NULL) { 	/* get addr. one by one */
		len = strlen(ptr);
		if ((ptr[len-1] == ',') || (ptr[len-1] == '\n')) ptr[len-1] = '\0';
		if (num < MAX_RCPT) {
			addressList[num] = (char*) calloc(len, sizeof(char));
			strcpy(addressList[num], ptr);
			num++;
		}
		else break;
	}

	return num;
}

/* make user\0user\0pass string */
void authCat(char *user, char *pass, char *target)
{
	int ulen, passlen, i;

	bzero(target, MAX_LEN);
	ulen = strlen(user);
	passlen = strlen(pass);
	strcpy(target, user);
	for (i=0; i<ulen; i++) target[ulen+1+i] = user[i];
	for (i=0; i<passlen; i++) target[ulen+ulen+2+i] = pass[i];
	target[ulen+ulen+passlen+2] = '\n';
}
